@@ -25,74 +25,64 @@ class StartLiveIndexRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'StartLiveIndex','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TokenId(self):
+	def get_TokenId(self): # String
 		return self.get_query_params().get('TokenId')
 
-	def set_TokenId(self,TokenId):
-		self.add_query_param('TokenId',TokenId)
-
-	def get_OssEndpoint(self):
+	def set_TokenId(self, TokenId):  # String
+		self.add_query_param('TokenId', TokenId)
+	def get_OssEndpoint(self): # String
 		return self.get_query_params().get('OssEndpoint')
 
-	def set_OssEndpoint(self,OssEndpoint):
-		self.add_query_param('OssEndpoint',OssEndpoint)
-
-	def get_AppName(self):
+	def set_OssEndpoint(self, OssEndpoint):  # String
+		self.add_query_param('OssEndpoint', OssEndpoint)
+	def get_AppName(self): # String
 		return self.get_query_params().get('AppName')
 
-	def set_AppName(self,AppName):
-		self.add_query_param('AppName',AppName)
-
-	def get_OssRamRole(self):
+	def set_AppName(self, AppName):  # String
+		self.add_query_param('AppName', AppName)
+	def get_OssRamRole(self): # String
 		return self.get_query_params().get('OssRamRole')
 
-	def set_OssRamRole(self,OssRamRole):
-		self.add_query_param('OssRamRole',OssRamRole)
-
-	def get_StreamName(self):
+	def set_OssRamRole(self, OssRamRole):  # String
+		self.add_query_param('OssRamRole', OssRamRole)
+	def get_StreamName(self): # String
 		return self.get_query_params().get('StreamName')
 
-	def set_StreamName(self,StreamName):
-		self.add_query_param('StreamName',StreamName)
-
-	def get_OssUserId(self):
+	def set_StreamName(self, StreamName):  # String
+		self.add_query_param('StreamName', StreamName)
+	def get_OssUserId(self): # String
 		return self.get_query_params().get('OssUserId')
 
-	def set_OssUserId(self,OssUserId):
-		self.add_query_param('OssUserId',OssUserId)
-
-	def get_OssBucket(self):
+	def set_OssUserId(self, OssUserId):  # String
+		self.add_query_param('OssUserId', OssUserId)
+	def get_OssBucket(self): # String
 		return self.get_query_params().get('OssBucket')
 
-	def set_OssBucket(self,OssBucket):
-		self.add_query_param('OssBucket',OssBucket)
-
-	def get_DomainName(self):
+	def set_OssBucket(self, OssBucket):  # String
+		self.add_query_param('OssBucket', OssBucket)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_InputUrl(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_InputUrl(self): # String
 		return self.get_query_params().get('InputUrl')
 
-	def set_InputUrl(self,InputUrl):
-		self.add_query_param('InputUrl',InputUrl)
-
-	def get_OwnerId(self):
+	def set_InputUrl(self, InputUrl):  # String
+		self.add_query_param('InputUrl', InputUrl)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Interval(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Interval(self): # Integer
 		return self.get_query_params().get('Interval')
 
-	def set_Interval(self,Interval):
-		self.add_query_param('Interval',Interval)
\ No newline at end of file
+	def set_Interval(self, Interval):  # Integer
+		self.add_query_param('Interval', Interval)
